@@ -10,14 +10,13 @@ import uuid
 from babel.core import Locale
 from imia import UserLike, UserToken
 from starlette import datastructures as ds, requests
-from starlette.datastructures import State
 from starlette.requests import empty_receive, empty_send
 from starlette.types import Receive, Scope, Send
 from starsessions import Session
 
 from kupala.storages.storages import Storage
 
-if t.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from kupala.application import Kupala
 
 
@@ -165,11 +164,7 @@ class Headers(requests.Headers):
     pass
 
 
-_A = t.TypeVar('_A', bound='Kupala')
-_S = t.TypeVar('_S', bound=State)
-
-
-class Request(requests.Request, t.Generic[_A, _S]):
+class Request(requests.Request):
     def __new__(cls, scope: Scope, receive: Receive = empty_receive, send: Send = empty_send) -> Request:
         if 'request' not in scope:
             instance = super().__new__(cls)
@@ -187,7 +182,7 @@ class Request(requests.Request, t.Generic[_A, _S]):
         return QueryParams(super().query_params)
 
     @property
-    def app(self) -> _A:
+    def app(self) -> 'Kupala':
         return self.scope['app']
 
     @property
@@ -267,10 +262,6 @@ class Request(requests.Request, t.Generic[_A, _S]):
             self.scope['_form_old_input'] = old_form_input
         return self.scope['_form_old_input']
 
-    @property
-    def state(self) -> _S:
-        return t.cast(_S, super().state)
-
     async def remember_form_data(self) -> None:
         """Flush current form data into session so it can be used on the next page to render form errors."""
         if 'session' in self.scope:
